#################################################################################################
##
## Copyright 2012-2024 CNRS, INPT, Inria
##  
## This file is part of qr_mumps.
##  
## qr_mumps is free software: you can redistribute it and/or modify
## it under the terms of the GNU Lesser General Public License as 
## published by the Free Software Foundation, either version 3 of 
## the License, or (at your option) any later version.
##  
## qr_mumps is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU Lesser General Public License for more details.
##  
## You can find a copy of the GNU Lesser General Public License
## in the qr_mumps/doc directory.
##
#################################################################################################
set(QRM_VERSION 3.0)

# relocatable package

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QRMConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/qrm" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(QRM_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin/")
set_and_check(QRM_INC_DIR "${PACKAGE_PREFIX_DIR}/include/")
set_and_check(QRM_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")

check_required_components(QRM)

# add metis as imported target if qrm built static
if (ON AND NOT ON)
  include("${CMAKE_CURRENT_LIST_DIR}/metisTargets.cmake")
endif()

# add scotch as imported target if qrm built static
if (ON AND NOT ON)
  include("${CMAKE_CURRENT_LIST_DIR}/scotchTargets.cmake")
endif()

# add amd as imported target if qrm built static
if (ON AND NOT ON)
  include("${CMAKE_CURRENT_LIST_DIR}/amdTargets.cmake")
endif()

# add amd as imported target if qrm built static
if (OFF AND NOT ON)
  include("${CMAKE_CURRENT_LIST_DIR}/starpuTargets.cmake")
endif()

# add cuda and cublas as imported target if qrm built static
if (OFF AND NOT ON)
  include("${CMAKE_CURRENT_LIST_DIR}/cudaTargets.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/cublasTargets.cmake")
endif()

include("${CMAKE_CURRENT_LIST_DIR}/qrm_commonTargets.cmake")
foreach(_arith d;s;z;c)
  include("${CMAKE_CURRENT_LIST_DIR}/${_arith}qrmTargets.cmake")
endforeach()
